==> spip_3.0.18.orig.tar.xz: spip/plugins-dist/sites/lang/sites_pt_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=pt_br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'articles_dispo' => 'Na fila',
	'articles_meme_auteur' => 'Todas as matérias desse autor',
	'articles_off' => 'Bloqueadas',
	'articles_publie' => 'Publicadas',
	'articles_refuse' => 'Removidas',
	'articles_tous' => 'Todas',
	'aucun_article_syndic' => 'Nenhuma matéria sindicada',
	'avis_echec_syndication_01' => 'A sindicação falhou: o backend informado é indecifrável ou não propõe nenhuma matéria.',
	'avis_echec_syndication_02' => 'A sindicação falhou: não foi possível acessar o backend deste site.',
	'avis_site_introuvable' => 'Site não encontrado',
	'avis_site_syndique_probleme' => 'Atenção: a sindicação deste site encontrou um problema; no momento, o sistema foi temporáriamente interrompido. Verifique o endereço do arquivo de sindicação deste site (<b>@url_syndic@</b>) e tente uma nova recuperação das informações.',
	'avis_sites_probleme_syndication' => 'Estes sites estão com problema de sindicação',
	'avis_sites_syndiques_probleme' => 'Estes sites sindicados provocaram um problema',

	// B
	'bouton_exporter' => 'Exportar',
	'bouton_importer' => 'Importar',
	'bouton_radio_modere_posteriori' => 'moderação à posteriori',
	'bouton_radio_modere_priori' => 'moderação à priori',
	'bouton_radio_non_syndication' => 'Sem sindicação',
	'bouton_radio_syndication' => 'Sindicação:',

	// C
	'confirmer_purger_syndication' => 'Tem certeza de que quer remover todas as matérias sindicadas desse site?',

	// E
	'entree_adresse_fichier_syndication' => 'Endereço do arquivo de sindicação:',
	'entree_adresse_site' => '<b>endereço do site</b> [Obrigatório]',
	'entree_description_site' => 'Descrição do site',
	'erreur_fichier_format_inconnu' => 'O formato do arquivo @fichier@ não é suportado.',
	'erreur_fichier_incorrect' => 'Impossível ler o arquivo.',

	// F
	'form_prop_nom_site' => 'Nome do site',

	// I
	'icone_article_syndic' => 'Martéria sindicada',
	'icone_articles_syndic' => 'Matérias sindicadas',
	'icone_controler_syndication' => 'Publicação das matérias sindicadas',
	'icone_modifier_site' => 'Editar este site',
	'icone_referencer_nouveau_site' => 'Referenciar um novo site',
	'icone_site_reference' => 'Sites referenciados',
	'icone_supprimer_article' => 'Remover essa matéria',
	'icone_supprimer_articles' => 'Remover essas matérias',
	'icone_valider_article' => 'Validar essa matéria',
	'icone_valider_articles' => 'Validar essas matérias',
	'icone_voir_sites_references' => 'Ver os sites referenciados',
	'info_1_article_syndique' => '1 matéria sindicada',
	'info_1_site' => '1 site',
	'info_1_site_importe' => '1 site foi importado',
	'info_a_valider' => '[para validar]',
	'info_aucun_article_syndique' => 'Nenhuma matéria sindicada',
	'info_aucun_site' => 'Nenhum site',
	'info_aucun_site_importe' => 'Não foi possível importar nenhum site.',
	'info_bloquer' => 'bloquear',
	'info_bloquer_lien' => 'bloquear este link',
	'info_derniere_syndication' => 'A última sindicação deste site foi efetuada em',
	'info_liens_syndiques_1' => 'links sindicados',
	'info_liens_syndiques_2' => 'aguardam validação.',
	'info_nb_articles_syndiques' => '@nb@ matérias sindicadas',
	'info_nb_sites' => '@nb@ sites',
	'info_nb_sites_importes' => '@nb@ sites foram importados',
	'info_nom_site_2' => '<b>Nome do site</b> [Obrigatório]',
	'info_panne_site_syndique' => 'Site sindicado com problemas',
	'info_probleme_grave' => 'problema de',
	'info_question_proposer_site' => 'Quem pode propôr os sites referenciados?',
	'info_retablir_lien' => 'reabilitar este link',
	'info_site_attente' => 'Website aguardando validação',
	'info_site_propose' => 'Site proposto em:',
	'info_site_reference' => 'Site referenciado online',
	'info_site_refuse' => 'Website recusado',
	'info_site_syndique' => 'Este site está sindicado...',
	'info_site_valider' => 'Sites para validar',
	'info_sites_referencer' => 'Referenciar um site',
	'info_sites_refuses' => 'Os sites recusados',
	'info_statut_site_1' => 'Este site está:',
	'info_statut_site_2' => 'Publicado',
	'info_statut_site_3' => 'Proposto',
	'info_statut_site_4' => 'Na lixeira',
	'info_syndication' => 'sindicação:',
	'info_syndication_articles' => 'matéria(s)',
	'item_bloquer_liens_syndiques' => 'Bloquear os links sindicados para validação',
	'item_gerer_annuaire_site_web' => 'Gerenciar um diretório de websites',
	'item_non_bloquer_liens_syndiques' => 'Não bloquear os links vindos da sindicação',
	'item_non_gerer_annuaire_site_web' => 'Desativar o diretório de websites',
	'item_non_utiliser_syndication' => 'Não utilizar a sindicação automática',
	'item_utiliser_syndication' => 'Utilizar a sindicação automática',

	// L
	'label_exporter_avec_mots_cles_1' => 'Exportar palavras-chave na forma de tags',
	'label_exporter_id_parent' => 'Exportar os sites da seção',
	'label_exporter_publie_seulement_1' => 'Exportar somente os sites publicados',
	'label_fichier_import' => 'Arquivo HTML',
	'label_importer_les_tags_1' => 'Importar tags na forma de palavras-chave',
	'label_importer_statut_publie_1' => 'Publicar automaticamente os sites',
	'lien_mise_a_jour_syndication' => 'Atualizar agora',
	'lien_nouvelle_recuperation' => 'Tentar uma nova recuperação dos dados',
	'lien_purger_syndication' => 'Excluir todas as matérias sindicadas',

	// N
	'nombre_articles_syndic' => '@nb@ artigos sindicados',

	// S
	'statut_off' => 'Remover',
	'statut_prop' => 'Na fila',
	'statut_publie' => 'Publicado',
	'syndic_choix_moderation' => 'O que fazer com os próximos links que venham deste site?',
	'syndic_choix_oublier' => 'O que fazer com os links que não constam mais do arquivo de sindicação?',
	'syndic_choix_resume' => 'Alguns sites divulgam o texto completo das matérias. Caso o mesmo esteja disponível, você deseja sindicar:',
	'syndic_lien_obsolete' => 'link obsoleto',
	'syndic_option_miroir' => 'bloqueá-los automaticamente',
	'syndic_option_oubli' => 'apagá-los (após @mois@ mois)',
	'syndic_option_resume_non' => 'O conteúdo completo das matérias ( em formato HTML)',
	'syndic_option_resume_oui' => 'um resumo básico (em formato texto)',
	'syndic_options' => 'Opções de sindicação:',

	// T
	'texte_expliquer_export_bookmarks' => 'Você pode exportar uma lista de sites no formato bookmark HTML, para permitir de importá-la em seu navigador ou em um serviço on line',
	'texte_expliquer_import_bookmarks' => 'Você pode importar uma lista de sites no formato bookmark HTML, a partir de seu navegador ou de um serviço on line de gerenciamento de bookmarks.',
	'texte_liens_sites_syndiques' => 'Os links gerados pelos sites sindicados podem ser bloqueados previamente; a configuração abaixo indica a opção padrão para os sites sindicados, após sua inclusão. É possível, em seguida, desbloquear cada link individualmente, ou escolher, site a site, o bloqueio de links originados de um ou outro site.',
	'texte_messages_publics' => 'Mensagens públicas da matéria:',
	'texte_non_fonction_referencement' => 'Você pode preferir não usar esta função automática, e indicar você mesmo os elementos relativos a este site...',
	'texte_referencement_automatique' => '<b>Referenciamento automatizado de um site</b><br />Você pode referenciar rapidamente um websites indicando abaixo o URL desejado, ou o endereço do seu arquivo de sindicação. O SPIP recuperará automaticamente as informações relativas ao site (título, descrição...).',
	'texte_referencement_automatique_verifier' => 'Por favor, verifique as informações fornecidas em <tt>@url@</tt> antes de se registrar.',
	'texte_syndication' => 'É possível baixar automaticamente a lista de novidades de um site, desde que ele o permita. Para isso, você deverá ativar a sindicação.
<blockquote><i>Alguns serviços de hospedagem desativam esta funcionalidade; neste caso, você não poderá usar a sindicação de conteúdo no seu site.</i></blockquote>',
	'titre_articles_syndiques' => 'Matérias sindicadas extraídas deste site',
	'titre_dernier_article_syndique' => 'Últimas matérias sindicadas',
	'titre_exporter_bookmarks' => 'Exportar bookmarks',
	'titre_importer_bookmarks' => 'Importar bookmarks',
	'titre_importer_exporter_bookmarks' => 'Importar e exportar bookmarks',
	'titre_page_sites_tous' => 'Os sites referenciados',
	'titre_referencement_sites' => 'Referenciamento de sites e sindicação',
	'titre_site_numero' => 'SITE NÚMERO:',
	'titre_sites_proposes' => 'Os sites propostos',
	'titre_sites_references_rubrique' => 'Os sites referenciados nesta seção',
	'titre_sites_syndiques' => 'Os sites sindicados',
	'titre_sites_tous' => 'Os sites referenciados',
	'titre_syndication' => 'Sindicação de sites',
	'tout_voir' => 'Ver todas as matérias sindicadas',

	// U
	'un_article_syndic' => '1 matéria sindicada'
);

?>

==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/sites/lang/sites_pt_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=pt_br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => 'A sindicação falhou: o backend informado é indecifrável ou não propõe nenhuma matéria.',
	'avis_echec_syndication_02' => 'A sindicação falhou: não foi possível acessar o backend deste site.',
	'avis_site_introuvable' => 'Site não encontrado',
	'avis_site_syndique_probleme' => 'Atenção: a sindicação deste site encontrou um problema; no momento, o sistema foi temporáriamente interrompido. Verifique o endereço do arquivo de sindicação deste site (<b>@url_syndic@</b>) e tente uma nova recuperação das informações.',
	'avis_sites_probleme_syndication' => 'Estes sites estão com problema de sindicação',
	'avis_sites_syndiques_probleme' => 'Estes sites sindicados provocaram um problema',

	// B
	'bouton_radio_modere_posteriori' => 'moderação à posteriori', # MODIF
	'bouton_radio_modere_priori' => 'moderação à priori', # MODIF
	'bouton_radio_non_syndication' => 'Sem sindicação',
	'bouton_radio_syndication' => 'Sindicação:',

	// E
	'entree_adresse_fichier_syndication' => 'Endereço do arquivo de sindicação:',
	'entree_adresse_site' => '<b>endereço do site</b> [Obrigatório]',
	'entree_description_site' => 'Descrição do site',

	// F
	'form_prop_nom_site' => 'Nome do site',

	// I
	'icone_modifier_site' => 'Editar este site',
	'icone_referencer_nouveau_site' => 'Referenciar um novo site',
	'icone_voir_sites_references' => 'Ver os sites referenciados',
	'info_a_valider' => '[para validar]',
	'info_bloquer' => 'bloquear',
	'info_bloquer_lien' => 'bloquear este link',
	'info_derniere_syndication' => 'A última sindicação deste site foi efetuada em',
	'info_liens_syndiques_1' => 'links sindicados',
	'info_liens_syndiques_2' => 'aguardam validação.',
	'info_nom_site_2' => '<b>Nome do site</b> [Obrigatório]',
	'info_panne_site_syndique' => 'Site sindicado com problemas',
	'info_probleme_grave' => 'problema de',
	'info_question_proposer_site' => 'Quem pode propôr os sites referenciados?',
	'info_retablir_lien' => 'reabilitar este link',
	'info_site_attente' => 'Website aguardando validação',
	'info_site_propose' => 'Site proposto em:',
	'info_site_reference' => 'Site referenciado online',
	'info_site_refuse' => 'Website recusado',
	'info_site_syndique' => 'Este site está sindicado...', # MODIF
	'info_site_valider' => 'Sites para validar',
	'info_sites_referencer' => 'Referenciar um site',
	'info_sites_refuses' => 'Os sites recusados',
	'info_statut_site_1' => 'Este site está:',
	'info_statut_site_2' => 'Publicado',
	'info_statut_site_3' => 'Proposto',
	'info_statut_site_4' => 'Na lixeira', # MODIF
	'info_syndication' => 'sindicação:',
	'info_syndication_articles' => 'matéria(s)',
	'item_bloquer_liens_syndiques' => 'Bloquear os links sindicados para validação',
	'item_gerer_annuaire_site_web' => 'Gerenciar um diretório de websites',
	'item_non_bloquer_liens_syndiques' => 'Não bloquear os links vindos da sindicação',
	'item_non_gerer_annuaire_site_web' => 'Desativar o diretório de websites',
	'item_non_utiliser_syndication' => 'Não utilizar a sindicação automática',
	'item_utiliser_syndication' => 'Utilizar a sindicação automática',

	// L
	'lien_mise_a_jour_syndication' => 'Atualizar agora',
	'lien_nouvelle_recuperation' => 'Tentar uma nova recuperação dos dados',

	// S
	'syndic_choix_moderation' => 'O que fazer com os próximos links que venham deste site?',
	'syndic_choix_oublier' => 'O que fazer com os links que não constam mais do arquivo de sindicação?',
	'syndic_choix_resume' => 'Alguns sites divulgam o texto completo das matérias. Caso o mesmo esteja disponível, você deseja sindicar:',
	'syndic_lien_obsolete' => 'link obsoleto',
	'syndic_option_miroir' => 'bloqueá-los automaticamente',
	'syndic_option_oubli' => 'apagá-los (após @mois@ mois)',
	'syndic_option_resume_non' => 'O conteúdo completo das matérias ( em formato HTML)',
	'syndic_option_resume_oui' => 'um resumo básico (em formato texto)',
	'syndic_options' => 'Opções de sindicação:',

	// T
	'texte_liens_sites_syndiques' => 'Os links gerados pelos sites sindicados podem ser bloqueados previamente; a configuração abaixo indica a opção padrão para os sites sindicados, após a sua inclusão. É possível, em seguida, desbloquear cada link individualmente, ou escolher, site a site, o bloqueio de links originados de um ou outro site.', # MODIF
	'texte_messages_publics' => 'Mensagens públicas da matéria:',
	'texte_non_fonction_referencement' => 'Você pode preferir não usar esta função automática, e indicar você mesmo os elementos relativos a este site...', # MODIF
	'texte_referencement_automatique' => '<b>Referenciamento automatizado de um site</b><br />Você pode referenciar rapidamente um websites indicando abaixo o URL desejado, ou o endereço do seu arquivo de sindicação. O SPIP recuperará automaticamente as informações relativas ao site (título, descrição...).', # MODIF
	'texte_referencement_automatique_verifier' => 'Por favor, verifique as informações fornecidas em <tt>@url@</tt> antes de se registrar.',
	'texte_syndication' => 'É possível recuperar automaticamente, desde que o site o permita, a lista das suas novidades. Para isso, você deverá ativar a sindicação.
  <blockquote><i>Alguns serviços de hospedagem desativam esta funcionalidade;
neste caso, você não poderá usar a sindicação de conteúdo no seu site.</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'Matérias sindicadas extraídas deste site',
	'titre_dernier_article_syndique' => 'Últimas matérias sindicadas',
	'titre_page_sites_tous' => 'Os sites referenciados',
	'titre_referencement_sites' => 'Referenciamento de sites e sindicação',
	'titre_site_numero' => 'SITE NÚMERO:',
	'titre_sites_proposes' => 'Os sites propostos',
	'titre_sites_references_rubrique' => 'Os sites referenciados nesta seção',
	'titre_sites_syndiques' => 'Os sites sindicados',
	'titre_sites_tous' => 'Os sites referenciados',
	'titre_syndication' => 'Sindicação de sites'
);

?>
